Package: reprex
Title: Prepare Reproducible Example Code via the Clipboard
Version: 2.1.1
Authors@R: c(
    person("Jennifer", "Bryan", , "jenny@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6983-2759")),
    person("Jim", "Hester", role = "aut",
           comment = c(ORCID = "0000-0002-2739-7082")),
    person("David", "Robinson", , "admiral.david@gmail.com", role = "aut"),
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-4757-117X")),
    person("Christophe", "Dervieux", , "cderv@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-4474-2498")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Convenience wrapper that uses the 'rmarkdown' package to
    render small snippets of code to target formats that include both code
    and output.  The goal is to encourage the sharing of small,
    reproducible, and runnable examples on code-oriented websites, such as
    <https://stackoverflow.com> and <https://github.com>, or in email. The
    user's clipboard is the default source of input code and the default
    target for rendered output. 'reprex' also extracts clean, runnable R
    code from various common formats, such as copy/paste from an R
    session.
License: MIT + file LICENSE
URL: https://reprex.tidyverse.org, https://github.com/tidyverse/reprex
BugReports: https://github.com/tidyverse/reprex/issues
Depends: R (>= 3.6)
Imports: callr (>= 3.6.0), cli (>= 3.2.0), clipr (>= 0.4.0), fs, glue,
        knitr (>= 1.23), lifecycle, rlang (>= 1.0.0), rmarkdown,
        rstudioapi, utils, withr (>= 2.3.0)
Suggests: covr, fortunes, miniUI, rprojroot, sessioninfo, shiny,
        spelling, styler (>= 1.2.0), testthat (>= 3.2.1)
VignetteBuilder: knitr
Config/Needs/website: dplyr, tidyverse/tidytemplate
Config/testthat/edition: 3
Config/testthat/parallel: TRUE
Config/testthat/start-first: knitr-options, venues, reprex
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
SystemRequirements: pandoc (>= 2.0) - https://pandoc.org/
NeedsCompilation: no
Packaged: 2024-07-06 00:20:55 UTC; jenny
Author: Jennifer Bryan [aut, cre] (<https://orcid.org/0000-0002-6983-2759>),
  Jim Hester [aut] (<https://orcid.org/0000-0002-2739-7082>),
  David Robinson [aut],
  Hadley Wickham [aut] (<https://orcid.org/0000-0003-4757-117X>),
  Christophe Dervieux [aut] (<https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd]
Maintainer: Jennifer Bryan <jenny@posit.co>
Repository: CRAN
Date/Publication: 2024-07-06 13:50:01 UTC
Built: R 4.6.0; ; 2026-04-28 13:42:58 UTC; unix
