# Generated by roxygen2: do not edit by hand

export(reprex)
export(reprex_addin)
export(reprex_clean)
export(reprex_document)
export(reprex_html)
export(reprex_invert)
export(reprex_locale)
export(reprex_r)
export(reprex_render)
export(reprex_rescue)
export(reprex_rtf)
export(reprex_selection)
export(reprex_slack)
import(fs)
import(rlang)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(lifecycle,deprecated)
