---
output: reprex::reprex_document
knit: reprex::reprex_render
---

Describe your issue very briefly here. Then show it with a minimal, self-contained example in the following R chunk.

```{r}
x <- 1
y <- "2"
x + y
```
