---
title: "How to use reprex"
---

Materials from an [RStudio webinar](https://resources.rstudio.com/webinars) delivered September 2018:

### Help me help you: Creating reproducible examples with reprex  

What is a reprex? It’s a **repr**oducible **ex**ample. Making a great reprex is both an art and a science and this webinar will cover both aspects. A reprex makes a conversation about code more efficient and pleasant for all. This comes up whenever you ask someone for help, report a bug in software, or propose a new feature. The reprex package (https://reprex.tidyverse.org) makes it especially easy to prepare R code as a reprex, in order to share on sites such as https://community.rstudio.com, https://github.com, or https://stackoverflow.com. The habit of making little, rigorous, self-contained examples also has the great side effect of making you think more clearly about your programming problems.

Webinar page: <https://resources.rstudio.com/webinars/help-me-help-you-creating-reproducible-examples-jenny-bryan>

<script src="https://fast.wistia.com/embed/medias/eu1gge6c34.jsonp" async></script><script src="https://fast.wistia.com/assets/external/E-v1.js" async></script><div class="wistia_responsive_padding" style="padding:56.25% 0 0 0;position:relative;"><div class="wistia_responsive_wrapper" style="height:100%;left:0;position:absolute;top:0;width:100%;"><div class="wistia_embed wistia_async_eu1gge6c34 videoFoam=true" style="height:100%;position:relative;width:100%"><div class="wistia_swatch" style="height:100%;left:0;opacity:0;overflow:hidden;position:absolute;top:0;transition:opacity 200ms;width:100%;"><img src="https://fast.wistia.com/embed/medias/eu1gge6c34/swatch" style="filter:blur(5px);height:100%;object-fit:contain;width:100%;" alt="Video of September 2018 RStudio webinar about reprex" onload="this.parentNode.style.opacity=1;" /></div></div></div></div>

Slides on SpeakerDeck: 

<https://speakerdeck.com/jennybc/reprex-reproducible-examples-with-r>

<script async class="speakerdeck-embed" data-id="a5eedf90acb648fab7a3f1f0a5bb8885" data-ratio="1.77777777777778" src="//speakerdeck.com/assets/embed.js"></script>

<!-- 
Video: <https://youtu.be/MmTPhGQWPUo>

<iframe width="560" height="315" src="https://www.youtube.com/embed/MmTPhGQWPUo?rel=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
-->

